@@ -1,18 +1,19 @@
 import requests
 
+
 class SerpsBot():
     def __init__(self, apikey):
         headers = {
             'Authorization': 'Bearer {}'.format(apikey)
         }
         self.headers = headers
-        self.apibase = 'https://serpsbot.com/api/v1/google-serps/'
-    
+        self.apibase = 'https://api.serpsbot.com/api/v1/google-serps/'
+
     def getresults(self, **kwargs):
         q = kwargs.get('q')
         hl = kwargs.get('hl', 'en-US')
         gl = kwargs.get('gl', 'us')
-        pages = kwargs.get('pages', 1)
+        page = kwargs.get('page', 1)
         duration = kwargs.get('duration', '')
         autocorrect = kwargs.get('autocorrect', '1')
 
@@ -20,7 +21,7 @@ class SerpsBot():
             'q': q,
             'hl': hl,
             'gl': gl,
-            'pages': pages,
+            'page': page,
             'duration': duration,
             'autocorrect': autocorrect
         }
